==> sql-processor-1.0.0-sources.jar: org/sqlproc/engine/impl/SqlMetaIfItem.java <==
package org.sqlproc.engine.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.sqlproc.engine.SqlFeature;

/**
 * A META SQL sub-element.
 * 
 * <p>
 * Schematically:
 * 
 * <pre>
 * SqlMetaIfItem
 *     SqlMetaText
 *     SqlMetaIdent
 *     SqlMetaConst
 *     SqlMetaAndOr for embedded {}, {&}, {|}
 *     SqlMetaIf for embedded {? }
 * </pre>
 * 
 * @author <a href="mailto:Vladimir.Hudec@gmail.com">Vladimir Hudec</a>
 */
class SqlMetaIfItem implements SqlMetaElement {

    /**
     * The internal slf4j logger.
     */
    final Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * The list of sub-elements based on ANTLR grammar.
     */
    List<SqlMetaElement> elements;

    /**
     * Creates a new instance. It's used from inside ANTLR parser.
     */
    SqlMetaIfItem() {
        this.elements = new ArrayList<SqlMetaElement>();
    }

    /**
     * Adds a new sub-element. It's used from inside ANTLR parser.
     * 
     * @param element
     *            new sub-element, based on ANTLR grammar
     */
    void addElement(SqlMetaElement element) {
        elements.add(element);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public SqlProcessResult process(SqlProcessContext ctx) {
        SqlProcessResult result = new SqlProcessResult();
        result.addTrue();
        StringBuilder s = new StringBuilder();
        result.setSql(s);
        boolean like = false;
        for (SqlMetaElement item : this.elements) {
            SqlProcessResult itemResult = item.process(ctx);
            if (itemResult.isAdd()) {
                s.append(itemResult.getSql());
                result.addInputValues(itemResult.getInputValues());
                if (ctx.isFeature(SqlFeature.SURROUND_QUERY_LIKE) && item instanceof SqlMetaIdent && like) {
                    for (String ident : itemResult.getInputValues().keySet()) {
                        itemResult
                                .getInputValues()
                                .get(ident)
                                .setLike(ctx.getFeature(SqlFeature.WILDCARD_CHARACTER),
                                        ctx.getFeatureAsInt(SqlFeature.SURROUND_QUERY_MIN_LEN));
                    }
                } else if (item instanceof SqlMetaText
                        && ctx.isFeature(SqlFeature.SURROUND_QUERY_LIKE)
                        && itemResult.getSql().toString().trim().toLowerCase()
                                .endsWith(ctx.getFeature(SqlFeature.LIKE_STRING))) {
                    like = true;
                } else
                    like = false;
            } else
                result.addFalse();
        }
        return result;
    }
}

==> sql-processor-1.1.0-sources.jar: org/sqlproc/engine/impl/SqlMetaIfItem.java <==
package org.sqlproc.engine.impl;

import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.sqlproc.engine.SqlFeature;

/**
 * A META SQL sub-element.
 * 
 * <p>
 * Schematically:
 * 
 * <pre>
 * SqlMetaIfItem
 *     SqlMetaText
 *     SqlMetaIdent
 *     SqlMetaConst
 *     SqlMetaAndOr for embedded {}, {&}, {|}
 *     SqlMetaIf for embedded {? }
 * </pre>
 * 
 * @author <a href="mailto:Vladimir.Hudec@gmail.com">Vladimir Hudec</a>
 */
class SqlMetaIfItem implements SqlMetaElement {

    /**
     * The internal slf4j logger.
     */
    final Logger logger = LoggerFactory.getLogger(getClass());

    /**
     * The list of sub-elements based on ANTLR grammar.
     */
    List<SqlMetaElement> elements;

    /**
     * Creates a new instance. It's used from inside ANTLR parser.
     */
    SqlMetaIfItem() {
        this.elements = new ArrayList<SqlMetaElement>();
    }

    /**
     * Adds a new sub-element. It's used from inside ANTLR parser.
     * 
     * @param element
     *            new sub-element, based on ANTLR grammar
     */
    void addElement(SqlMetaElement element) {
        elements.add(element);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public SqlProcessResult process(SqlProcessContext ctx) {
        SqlProcessResult result = new SqlProcessResult();
        result.addTrue();
        StringBuilder s = new StringBuilder();
        result.setSql(s);
        boolean like = false;
        for (SqlMetaElement item : this.elements) {
            SqlProcessResult itemResult = item.process(ctx);
            if (itemResult.isAdd()) {
                s.append(itemResult.getSql());
                result.addInputValues(itemResult.getInputValues());
                result.addOutputValues(itemResult.getOutputValues());
                if (SqlProcessContext.isFeature(SqlFeature.SURROUND_QUERY_LIKE) && item instanceof SqlMetaIdent && like) {
                    for (String ident : itemResult.getInputValues().keySet()) {
                        itemResult
                                .getInputValues()
                                .get(ident)
                                .setLike(SqlProcessContext.getFeature(SqlFeature.WILDCARD_CHARACTER),
                                        SqlProcessContext.getFeatureAsInt(SqlFeature.SURROUND_QUERY_MIN_LEN));
                    }
                } else if (item instanceof SqlMetaText
                        && SqlProcessContext.isFeature(SqlFeature.SURROUND_QUERY_LIKE)
                        && itemResult.getSql().toString().trim().toLowerCase()
                                .endsWith(SqlProcessContext.getFeature(SqlFeature.LIKE_STRING))) {
                    like = true;
                } else
                    like = false;
            } else
                result.addFalse();
        }
        return result;
    }
}
